// HelloWorld.cpp
#include "stdafx.h"

//Include novaPDF headers
#include "..\..\..\include\novaOptions.h"
#include "..\..\..\include\novaEvents.h"

//NovaPdfOptions
#include "..\..\..\include\novapi.h"

#include "nova.h"

//name of novaPDF Printer Demo
#define PRINTER_NAME    L"novaPDF SDK 9"

//text to be written in the PDF file
#define PDF_TEXT        L"Hello world!"

//PDF file name
#define PDF_FILE_NAME   L"HelloWorld.pdf"

//Print profile name
#define PROFILE_NAME       L"HelloWorld Profile" 
#define PROFILE_IS_PUBLIC  0

//entry point for the console application
int _tmain(int argc, _TCHAR* argv[])
{
	HRESULT hr = S_OK;

	//initialize COM
	hr = CoInitialize(NULL);
	if (FAILED (hr)) 
	{ 
		MessageBox(NULL, L"Failed to initialize COM", L"novaPDF", MB_OK); 
		return hr; 
	} 

	//create one NovaPdfOptions instance
	INovaPdfOptions90 *pNova = 0;
	hr = CoCreateInstance(__uuidof(NovaPdfOptions90), NULL, CLSCTX_INPROC_SERVER, __uuidof(INovaPdfOptions90), (LPVOID*) &pNova);

	if (FAILED(hr))   
	{
		MessageBox(NULL, L"Failed to create novaPDF COM object", L"novaPDF", MB_OK); 
		return hr;
	}

	// initialize the NovaPdfOptions object to use with a printer licensed for SDK
	// if you have an application license for novaPDF SDK, 
	// pass the license key to the Initialize() function
	hr = pNova->Initialize(PRINTER_NAME, L"");

	if (SUCCEEDED(hr)) 
	{
		LPWSTR pwsOldActiveProfileID = NULL;
		LPWSTR pwsNewProfileID = NULL;

		hr = pNova->GetActiveProfile(&pwsOldActiveProfileID);

		//create a new profile with default settings
		hr = pNova->AddProfile(PROFILE_NAME, PROFILE_IS_PUBLIC, &pwsNewProfileID);

		//load the newly created profile
		if (SUCCEEDED(hr) && pwsNewProfileID) 
		{
			hr = pNova->LoadProfile(pwsNewProfileID);
		}
		else
		{
			MessageBox(NULL, L"Failed to create profile", L"novaPDF", MB_OK); 
			return hr;
		}

		// set novaPDF options 
		// uncomment the function calls for the options you wish to set and change the options in nova.cpp unit
		
		//DO NOT OPEN PDF 
		//an Open action is added by default in the profile - delete or disable this open action
		//pNova->DisableActionType(NOVA_ACTION_OPEN);

		//AddProfileOptions(pNova); 
		//AddSaveOptions(pNova); 
		//AddMergeOptions(pNova);
		//AddDocumentInformation(pNova);
		//AddDocumentXMPMetadata(pNova);
		//AddViewerOptions(pNova);
		//AddLinksOptions(pNova);
		//AddAdvancedOptions(pNova);
		//AddGraphicsOptions(pNova);
		//AddEmbedFontsOptions(pNova);
		//AddBookmarksDefinitions(pNova);
		//AddSecurity(pNova);
		//AddWatermarkImage(pNova);
		//AddWatermarkText(pNova);
		//AddPageContentOptions(pNova);
		//AddOverlayOptions(pNova);
		//AddSignatureOptions(pNova);
		//AddActionsOptions(pNova);

		//save profile changes
		hr = pNova->SaveProfile();
		//set as active profile for printer
		pNova->SetActiveProfile(pwsNewProfileID);

		HANDLE     hPrinter;
		PDEVMODEW  pDevmode = NULL;
		PRINTER_DEFAULTS pd = { NULL, NULL, PRINTER_ACCESS_USE };

		pNova->RegisterNovaEvent(NOVAPDF_EVENT_ACTIONS);

		//start print job
		if (OpenPrinter(PRINTER_NAME, &hPrinter, &pd))
		{
			//get default printer DEVMODE      
			int nSize = DocumentProperties(NULL, hPrinter, PRINTER_NAME, NULL, NULL, 0);
			pDevmode = (PDEVMODEW)LocalAlloc(LPTR, nSize);
			DocumentProperties(NULL, hPrinter, PRINTER_NAME, pDevmode, NULL, DM_OUT_BUFFER);

			//set page size in DEVMODE
			pDevmode->dmPaperSize = DMPAPER_USER;
			pDevmode->dmPaperLength = 2970;
			pDevmode->dmPaperWidth = 2100;
			pDevmode->dmFields = DM_PAPERSIZE | DM_PAPERLENGTH | DM_PAPERWIDTH;
			DocumentProperties(NULL, hPrinter, PRINTER_NAME, pDevmode, pDevmode, DM_IN_BUFFER | DM_OUT_BUFFER);

			//Print a page
			HDC hDC = CreateDC(L"", PRINTER_NAME, NULL, pDevmode);
			DOCINFO docInfo = {sizeof(DOCINFO)};
			//document name
			docInfo.lpszDocName = PDF_FILE_NAME; 
			StartDoc(hDC,&docInfo);
			StartPage(hDC);
			// Draw text on page
			TextOut(hDC, 100, 80, PDF_TEXT, (int) wcslen(PDF_TEXT)); 
			EndPage(hDC);
			EndDoc(hDC);
			DeleteDC(hDC);

			//print job sent to printer
			MessageBox(NULL, L"Print job finished", L"novaPDF", MB_OK); 

			LocalFree(pDevmode);
			ClosePrinter(hPrinter);
		}
		else
		{
			WCHAR wsMessage[255];
			wsprintf(wsMessage, L"OpenPrinter failed, error = %d", GetLastError());
			MessageBox(NULL, wsMessage, L"novaPDF", MB_OK); 
		}

		BOOL bTimeout;
		pNova->WaitForNovaEvent(120000, &bTimeout);

		//restore default profile
		pNova->SetActiveProfile(pwsOldActiveProfileID);

		//delete newly created profile
		pNova->DeleteProfile(pwsNewProfileID);
		//free memory
		CoTaskMemFree(pwsNewProfileID);
		if(pwsOldActiveProfileID)
		{
			CoTaskMemFree(pwsOldActiveProfileID);
		}
	}
	else
	{
		MessageBox(NULL, L"Failed to initialize novaPDF Printer", L"novaPDF", MB_OK); 
	}

	//release NovaPdfOptions
	pNova->Release();
	CoUninitialize();
	return 0;
}
