#include "stdafx.h"

//Include novaPDF headers
#include "..\..\..\include\novaOptions.h"

//NovaPdfOptions
#include "..\..\..\include\novapi.h"

//------------------------------------------------------------------------------------------//
//-------------------------------------  PROFILE  -----------------------------------------//
//------------------------------------------------------------------------------------------//

void AddProfileOptions(INovaPdfOptions90 *pNova)
{
	//profile author
	pNova->SetOptionString(NOVAPDF_PROFILE_AUTHOR, L"Hello World application");
	//profile description
	pNova->SetOptionString(NOVAPDF_PROFILE_DESCRIPTION, L"Hello World application settings");
	//PDF version
	pNova->SetOptionLong(NOVAPDF_PDF_VERSION, PDF_VERSION_17);
	//generate PDFA compliant docs (require PDF version 1.4)
	pNova->SetOptionBool(NOVAPDF_PDFA, FALSE);
	//choose between PDFA/1a or PDFA/1b standards
	pNova->SetOptionLong(NOVAPDF_PDFA_VERSION, PDFA_1A);
	//generate linearized docs
	pNova->SetOptionBool(NOVAPDF_PDF_LINEARIZE, FALSE);
}

//------------------------------------------------------------------------------------------//
//-------------------------------------  ADVANCED  -----------------------------------------//
//------------------------------------------------------------------------------------------//

void AddAdvancedOptions(INovaPdfOptions90 *pNova)
{
	//advanced options
	pNova->SetOptionBool(NOVAPDF_ADV_OPTIMIZE_TEXT, TRUE);
	pNova->SetOptionBool(NOVAPDF_ADV_OPTIMIZE_IMAGE, FALSE);
	pNova->SetOptionBool(NOVAPDF_ADV_SILENT_PRINT, FALSE);
	pNova->SetOptionBool(NOVAPDF_ADV_CORRECT_FILLCOLOR, FALSE);
	pNova->SetOptionBool(NOVAPDF_ADV_CORRECT_LINEWIDTH, FALSE);
	pNova->SetOptionBool(NOVAPDF_ADV_IGNORE_EMPTY_PAGES, FALSE);
	pNova->SetOptionBool(NOVAPDF_ADV_VERIFY_FILE, FALSE);
	pNova->SetOptionBool(NOVAPDF_ADV_COPIES_ADD_PAGE, FALSE);
	pNova->SetOptionBool(NOVAPDF_ADV_COPIES_ONLY_ODD, FALSE);
}

//------------------------------------------------------------------------------------------//
//-------------------------------------  WATERMARK IMAGE -----------------------------------//
//------------------------------------------------------------------------------------------//

void AddWatermarkImage(INovaPdfOptions90 *pNova)
{
	LPWSTR pWtmImageId = NULL, pLayoutImageId = NULL;

	pNova->AddWatermarkImage(&pWtmImageId, &pLayoutImageId);
	//metadata
	pNova->SetWatermarkImageOptionString(pWtmImageId, NOVAPDF_WTM_IMG_NAME, L"WtmImage");
	pNova->SetWatermarkImageOptionString(pWtmImageId, NOVAPDF_WTM_IMG_AUTHOR, L"Hello World application");
	pNova->SetWatermarkImageOptionString(pWtmImageId, NOVAPDF_WTM_IMG_DESCRIPTION, L"image watermark");
	//watermark image file
	pNova->SetWatermarkImageOptionString(pWtmImageId, NOVAPDF_WTM_IMG_IMAGE_FILE_NAME, L"copy.png");
	pNova->SetWatermarkImageOptionLong(pWtmImageId, NOVAPDF_WTM_IMG_IMAGE_LOCATION, LOCATION_TYPE_LOCAL);
	pNova->SetWatermarkImageOptionString(pWtmImageId, NOVAPDF_WTM_IMG_IMAGE_USER_NAME, L"");
	pNova->SetWatermarkImageOptionEncryptedString(pWtmImageId, NOVAPDF_WTM_IMG_IMAGE_USER_PASSWORD, L"");
	//use transparency
	pNova->SetWatermarkImageOptionBool(pWtmImageId, NOVAPDF_WTM_IMG_IMAGE_TRANSPARENCY, TRUE);
	pNova->SetWatermarkImageOptionLong(pWtmImageId, NOVAPDF_WTM_IMG_IMAGE_TRANSP_COLOR, RGB(0,0,0));
	//opacity
	pNova->SetWatermarkImageOptionLong(pWtmImageId, NOVAPDF_WTM_IMG_IMAGE_OPACITY, 50);
	//color variation
	pNova->SetWatermarkImageOptionLong(pWtmImageId, NOVAPDF_WTM_IMG_COLOR_VARIATION, 0);
	//visibility
	pNova->SetWatermarkImageOptionBool(pWtmImageId, NOVAPDF_WTM_IMG_VISIBILITY_VIEW, TRUE);
	pNova->SetWatermarkImageOptionBool(pWtmImageId, NOVAPDF_WTM_IMG_VISIBILITY_PRINT, TRUE);
	pNova->SetWatermarkImageOptionBool(pWtmImageId, NOVAPDF_WTM_IMG_VISIBILITY_EXPORT, TRUE);

	//LAYOUT
	//metadata
	pNova->SetLayoutOptionString(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_NAME, L"WtmImage Layout");
	pNova->SetLayoutOptionString(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_AUTHOR, L"Hello World application");
	pNova->SetLayoutOptionString(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_DESCRIPTION, L"image watermark position on page");

	//anchors
	//offset is set as percentage or thousands of mm
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_LEFTANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_LEFTANCHOR_OFFSET, 10); 
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_LEFTANCHOR_USE_PERCENT, TRUE);

	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_RIGHTANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_RIGHTANCHOR_OFFSET, 50000);
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_RIGHTANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_TOPANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_TOPANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_TOPANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_BOTTOMANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_VERTANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_VERTLANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_VERTANCHOR_USE_PERCENT, TRUE);

	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_HORIZANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_HORIZANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_HORIZANCHOR_USE_PERCENT, FALSE);

	//aspect ratio
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_USE_ASPECT_RATIO, TRUE);
	//allow stretch with anchors when print on a different page size or layout
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_ALLOW_STRETCH, FALSE);

	//pages
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_FIRSTPAGE, FALSE);
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_LASTPAGE, FALSE);
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_ODDPAGE, FALSE);
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_EVENPAGE, FALSE);
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_ALLPAGE, TRUE);
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_PAGES, FALSE);
	pNova->SetLayoutOptionString(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_PAGERANGE, L"1-2");
	
	//Width / Height
	//thousands of mm
	pNova->SetLayoutOptionFloat(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_OBJECT_WIDTH, 100000);
	pNova->SetLayoutOptionFloat(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_OBJECT_HEIGHT, 100000);

	//Rotation
	//radians
	pNova->SetLayoutOptionFloat(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_ROTATION, 0);

	//ZIndex (multiple of 5) - objects with higher ZIndex will be above the ones with smaller ZIndex
	pNova->SetLayoutOptionLong(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_ZINDEX, 15);
	
	//Border
	pNova->SetLayoutOptionBool(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_USE_BORDER, TRUE);
	pNova->SetLayoutOptionLong(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_BORDER_POSITION, 0);
	pNova->SetLayoutOptionLong(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_BORDER_WIDTH, 2000);
	pNova->SetLayoutOptionLong(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_BORDER_STYLE, BORDER_STYLE_SOLID);
	pNova->SetLayoutOptionLong(pWtmImageId, pLayoutImageId, NOVAPDF_LAYOUT_BORDER_COLOR, RGB(255,120,200));
	
	CoTaskMemFree(pWtmImageId);
	CoTaskMemFree(pLayoutImageId);
}

//------------------------------------------------------------------------------------------//
//-------------------------------------  WATERMARK TEXT ------------------------------------//
//------------------------------------------------------------------------------------------//

void AddWatermarkText(INovaPdfOptions90 *pNova)
{
	LPWSTR pWtmTextd = NULL, pLayoutTextId = NULL;

	pNova->AddWatermarkText(&pWtmTextd, &pLayoutTextId);
	//metadata
	pNova->SetWatermarkTextOptionString(pWtmTextd, NOVAPDF_WTM_TXT_NAME, L"WtmText");
	pNova->SetWatermarkTextOptionString(pWtmTextd, NOVAPDF_WTM_TXT_AUTHOR, L"Hello World application");
	pNova->SetWatermarkTextOptionString(pWtmTextd, NOVAPDF_WTM_TXT_DESCRIPTION, L"text image");
	//watermark text
	pNova->SetWatermarkTextOptionString(pWtmTextd, NOVAPDF_WTM_TXT_WATERMARK_TEXT, L"Watermark");
	//font
	pNova->SetWatermarkTextOptionString(pWtmTextd, NOVAPDF_WTM_TXT_FONT_NAME, L"Arial");
	pNova->SetWatermarkTextOptionLong(pWtmTextd, NOVAPDF_WTM_TXT_FONT_TYPE, NOVA_FONTTYPE_TRUETYPE);
	pNova->SetWatermarkTextOptionLong(pWtmTextd, NOVAPDF_WTM_TXT_FONT_SIZE, 74);
	//font style
	pNova->SetWatermarkTextOptionBool(pWtmTextd, NOVAPDF_WTM_TXT_FONT_BOLD, TRUE);
	pNova->SetWatermarkTextOptionBool(pWtmTextd, NOVAPDF_WTM_TXT_FONT_ITALIC, TRUE);
	pNova->SetWatermarkTextOptionBool(pWtmTextd, NOVAPDF_WTM_TXT_FONT_OUTLINE, FALSE);
	pNova->SetWatermarkTextOptionBool(pWtmTextd, NOVAPDF_WTM_TXT_FONT_UNDERLINE, FALSE);
	//font color
	pNova->SetWatermarkTextOptionLong(pWtmTextd, NOVAPDF_WTM_TXT_FONT_COLOR, RGB(32,178,169));
	//opacity
	pNova->SetWatermarkTextOptionLong(pWtmTextd, NOVAPDF_WTM_TXT_OPACITY, 50);
	//visibility
	pNova->SetWatermarkTextOptionBool(pWtmTextd, NOVAPDF_WTM_TXT_VISIBILITY_VIEW, TRUE);
	pNova->SetWatermarkTextOptionBool(pWtmTextd, NOVAPDF_WTM_TXT_VISIBILITY_PRINT, TRUE);
	pNova->SetWatermarkTextOptionBool(pWtmTextd, NOVAPDF_WTM_TXT_VISIBILITY_EXPORT, TRUE);
	
	//LAYOUT
	//metadata
	pNova->SetLayoutOptionString(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_NAME, L"WtmText Layout");
	pNova->SetLayoutOptionString(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_AUTHOR, L"Hello World application");
	pNova->SetLayoutOptionString(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_DESCRIPTION, L"text watermark position on page");

	//anchors
	//offset is set as percentage or thousands of mm
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_LEFTANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_LEFTANCHOR_OFFSET, 10);
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_LEFTANCHOR_USE_PERCENT, TRUE);

	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_RIGHTANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_RIGHTANCHOR_OFFSET, 20000);
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_RIGHTANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_TOPANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_TOPANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_TOPANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_BOTTOMANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_VERTANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_VERTLANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_VERTANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_HORIZANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_HORIZANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_HORIZANCHOR_USE_PERCENT, FALSE);

	//aspect ratio
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_USE_ASPECT_RATIO, TRUE);
	//allow stretch with anchors when print on a different page size or layout
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_ALLOW_STRETCH, FALSE);

	//pages
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_FIRSTPAGE, FALSE);
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_LASTPAGE, FALSE);
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_ODDPAGE, FALSE);
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_EVENPAGE, FALSE);
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_ALLPAGE, TRUE);
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_PAGES, FALSE);
	pNova->SetLayoutOptionString(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_PAGERANGE, L"1-2");

	//ZIndex (multiple of 5) - objects with higher ZIndex will be above the ones with smaller ZIndex
	pNova->SetLayoutOptionLong(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_ZINDEX, 20);

	//Rotation (radians)
	//radians
	pNova->SetLayoutOptionFloat(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_ROTATION, (float)0.94);

	//Border
	pNova->SetLayoutOptionBool(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_USE_BORDER, FALSE);
	pNova->SetLayoutOptionLong(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_BORDER_POSITION, 0);
	pNova->SetLayoutOptionLong(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_BORDER_WIDTH, 2000);
	pNova->SetLayoutOptionLong(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_BORDER_STYLE, BORDER_STYLE_SOLID);
	pNova->SetLayoutOptionLong(pWtmTextd, pLayoutTextId, NOVAPDF_LAYOUT_BORDER_COLOR, RGB(255,120,200));
	
	CoTaskMemFree(pWtmTextd);
	CoTaskMemFree(pLayoutTextId);
}

//------------------------------------------------------------------------------------------//
//-------------------------------------  BOOKMARKS -----------------------------------------//
//------------------------------------------------------------------------------------------//

void AddBookmarksDefinitions(INovaPdfOptions90 *pNova)
{
	SHORT nDefinition, i, nCount = 0;

	//Enable bookmarks
	pNova->SetOptionBool(NOVAPDF_BMARK_EN_AUTO_DET_BMARKS, TRUE);

	//novaPDF driver will serach the text in the printed document, and if some text matches a bookmark definition
	//(for font, style, ssize, color) a bookmark with this text will be added in the pdf file.

	//if default profile contains some definitions, delete them
	pNova->GetBookmarkDefinitionCount(&nCount);
	for (i = nCount - 1; i >= 0; i--)
	{
		pNova->DeleteBookmarkDefinition(i);
	}

	//add new definition
	pNova->AddBookmarkDefinition(0, //Heading index
		TRUE, //definition is enabled
		TRUE, //check font name in the printed text
		L"Batang", //font name
		NOVA_FONTTYPE_TRUETYPE, //font type
		TRUE, //check font style in the printed text
		TRUE,  //bold font
		FALSE,  //italic font
		TRUE, //check font size in the printed text
		22, //font size
		(float)0.4, //font size aproximation
		FALSE, //check font color in the printed text
		RGB(255, 0, 0), //font color
		TRUE, //display bookmark as bold in pdf
		FALSE, //display bookmark as italic in pdf,
		RGB(0, 0, 255),  //display bookmark with this color in pdf
		&nDefinition //definition number
		);

    //Change general bookmarks settings
    pNova->SetOptionBool(NOVAPDF_BMK_ALLOW_MULTILINE, 1);
    pNova->SetOptionBool(NOVAPDF_BMK_MATCH_ALL_LEVELS, 1);
    pNova->SetOptionLong(NOVAPDF_BMK_USE_LEVELS, 1);
    pNova->SetOptionLong(NOVAPDF_BMK_OPEN_TO_LEVEL, 1);

    //Add root bookmark
    pNova->SetOptionBool(NOVAPDF_BMK_ROOT_ENABLED, 1);
	pNova->SetOptionString(NOVAPDF_BMK_ROOT_NAME, L"Document - [T]");
    pNova->SetOptionBool(NOVAPDF_BMK_ROOT_BOLD, 0);
    pNova->SetOptionBool(NOVAPDF_BMK_ROOT_ITALIC, 1);
    pNova->SetOptionLong(NOVAPDF_BMK_ROOT_COLOR, RGB(0,255,0));

}

//------------------------------------------------------------------------------------------//
//--------------------------------  DOCUMENT INFORMATION  ----------------------------------//
//------------------------------------------------------------------------------------------//

void AddDocumentInformation(INovaPdfOptions90 *pNova)
{
	//add document information
	pNova->SetOptionBool(NOVAPDF_INFO_ENABLE, TRUE);
	//show a dialog before printing each document to enter doc info
	pNova->SetOptionBool(NOVAPDF_SHOW_DOCINFO_DLG, FALSE);
	//pdf document information
	pNova->SetOptionString(NOVAPDF_DOCINFO_TITLE, L"My Doc Title");
	pNova->SetOptionString(NOVAPDF_DOCINFO_SUBJECT, L"My Doc Subject");
	pNova->SetOptionString(NOVAPDF_DOCINFO_AUTHOR, L"My Doc Author");
	pNova->SetOptionString(NOVAPDF_DOCINFO_CREATOR, L"My Doc Creator");
	pNova->SetOptionString(NOVAPDF_DOCINFO_KEYWORDS, L"keyword1, keyword2,...");
}

//------------------------------------------------------------------------------------------//
//--------------------------------  DOCUMENT METADATA --------------------------------------//
//------------------------------------------------------------------------------------------//

void AddDocumentXMPMetadata(INovaPdfOptions90 *pNova)
{
	//add XMP metadata to PDF
	pNova->SetOptionBool(NOVAPDF_ADD_XMP_METADATA, TRUE);
	//copyright information
	pNova->SetOptionString(NOVAPDF_COPYRIGHT_TEXT, L"My Doc Copyright Text");
	pNova->SetOptionString(NOVAPDF_COPYRIGHT_URL, L"My Doc Copyright URL");
	pNova->SetOptionLong(NOVAPDF_COPYRIGHT_TYPE, COPYRIGHT_TYPE_COPYRIGHTED);
}

//------------------------------------------------------------------------------------------//
//--------------------------------  VIEWER OPTIONS  ----------------------------------------//
//------------------------------------------------------------------------------------------//

void AddViewerOptions(INovaPdfOptions90 *pNova)
{

	pNova->SetOptionBool(NOVAPDF_INFO_VIEWER_ENABLE, TRUE);

	pNova->SetOptionBool(NOVAPDF_VIEWOP_HIDE_TOOLBARS, TRUE);
	pNova->SetOptionBool(NOVAPDF_VIEWOP_SHOW_DOCTITLE, TRUE);
	pNova->SetOptionBool(NOVAPDF_VIEWOP_HIDE_MENUBAR, TRUE);
	pNova->SetOptionBool(NOVAPDF_VIEWOP_RESIZE_WINDOW, TRUE);
	pNova->SetOptionBool(NOVAPDF_VIEWOP_HIDE_USER, TRUE);

	pNova->SetOptionLong(NOVAPDF_VIEWOP_TRANSITION_TYPE, TRANSITION_TYPE_REPLACE);
	pNova->SetOptionLong(NOVAPDF_VIEWOP_TRANSITION_DIRECTION, TRANSITION_DIR_VERT);
	pNova->SetOptionLong(NOVAPDF_VIEWOP_TRANSITION_DURATION, 2);
	pNova->SetOptionLong(NOVAPDF_VIEWOP_PAGE_DURATION, 2);

	pNova->SetOptionBool(NOVAPDF_VIEWOP_USE_START_PAGE, TRUE);
	pNova->SetOptionLong(NOVAPDF_VIEWOP_START_PAGE, 1);

	pNova->SetOptionLong(NOVAPDF_VIEWOP_ZOOM, PAGE_MAGN_VIEWERDEFAULT);
	pNova->SetOptionLong(NOVAPDF_VIEWOP_PAGE_LAYOUT, PAGE_LAY_VIEWERDEF);
	pNova->SetOptionLong(NOVAPDF_VIEWOP_PAGE_MODE, PAGE_MODE_VIEWERDEFAULT);
	pNova->SetOptionLong(NOVAPDF_VIEWOP_PAGE_SCALING, PAGE_SCALE_APPDEFAULT);
	pNova->SetOptionLong(NOVAPDF_VIEWOP_FULLSCREEN, FULLSCREEN_VIEWERDEF);
}

//------------------------------------------------------------------------------------------//
//----------------------------------------  SECURITY  --------------------------------------//
//------------------------------------------------------------------------------------------//

void AddSecurity(INovaPdfOptions90 *pNova)
{
	//first enable security - mandatory
	pNova->SetOptionBool(NOVAPDF_SEC_ENABLE, TRUE);
	//if a dialog should be shown before printing wach document, to change password
	pNova->SetOptionBool(NOVAPDF_SHOW_SECURITY_DLG, FALSE);
	//level
	pNova->SetOptionLong(NOVAPDF_SECURITY_LEVEL, SECURITY_128AES);
	//then set security flags: 1 if it is allowed, 0 if not
	//print document
	pNova->SetOptionBool(NOVAPDF_SECURITY_FLAG_PRINTDOC, TRUE);
	//modify document content
	pNova->SetOptionBool(NOVAPDF_SECURITY_FLAG_MODIFYDOC, TRUE);
	//extract text and grapics
	pNova->SetOptionBool(NOVAPDF_SECURITY_FLAG_EXTRACTTEXT, TRUE);
	//modify annotations, fill forms
	pNova->SetOptionBool(NOVAPDF_SECURITY_FLAG_MODIFYANNOTATION, TRUE);
	//advanced fill forms
	pNova->SetOptionBool(NOVAPDF_SECURITY_FLAG_ADVANCEDFILL, FALSE);
	//advanced extract text and graphics
	pNova->SetOptionBool(NOVAPDF_SECURITY_FLAG_ADVANCEDEXTRACT, TRUE);
	//assemble the document
	pNova->SetOptionBool(NOVAPDF_SECURITY_FLAG_ASSEMBLEDOC, TRUE);
	//print at high resolution
	pNova->SetOptionBool(NOVAPDF_SECURITY_FLAG_PRINTHIGHRES, TRUE);

	//passwords are set as encrypted strings (owner password is mandatory, user password is optional)
	//user password for opening the PDF
	pNova->SetOptionEncryptedString(NOVAPDF_SECURITY_USER_PASSWORD, L"my user password");
	//owner password for changing PDF security
	pNova->SetOptionEncryptedString(NOVAPDF_SECURITY_OWNER_PASSWORD, L"my owner password");

	//encrypt XMP metadata
	pNova->SetOptionBool(NOVAPDF_SECURITY_ENCRYPT_XMP, TRUE);
}

//------------------------------------------------------------------------------------------//
//--------------------------------------  DETECT LINKS  ------------------------------------//
//------------------------------------------------------------------------------------------//

void AddLinksOptions(INovaPdfOptions90 *pNova)
{
	// detect link / URL options
	//first enable links option - mandatory
	pNova->SetOptionBool(NOVAPDF_URL_ANALIZE, TRUE);
	//flag to detect or not file links
	pNova->SetOptionBool(NOVAPDF_URL_DETECT_FILES, TRUE);
	//when detecting file links, check if the file actually exists (1-check, 0-do not check)
	pNova->SetOptionBool(NOVAPDF_URL_CHECK_FILE_EXISTS, TRUE);
	//how to show the links in the pdf file
	pNova->SetOptionBool(NOVAPDF_URL_UNDERLINE, TRUE);
	//set links color blue
	pNova->SetOptionBool(NOVAPDF_URL_OVERWRITE_COLOR, TRUE);
	pNova->SetOptionLong(NOVAPDF_URL_COLOR, RGB(0,0,255));
}


//------------------------------------------------------------------------------------------//
//--------------------------------------  FONTS OPTIONS  -----------------------------------//
//------------------------------------------------------------------------------------------//

void AddEmbedFontsOptions(INovaPdfOptions90 *pNova)
{
	//embed all used fionts in the pdf file 
	pNova->SetOptionBool(NOVAPDF_FONTS_EMBED_ALL_USED_FONTS, TRUE);
	//embed only a subset of the fonts (only the characters that are used in the document)
	//embed all fonts has to be set too, otherwise fonts will not be embedded at all
	pNova->SetOptionBool(NOVAPDF_FONTS_EMBED_SUBSETS, TRUE);
	//some fonts cannot be embedded because their license does not allow the font to be embedded
	//but with the next option you can force to embed licensed fonts
	pNova->SetOptionBool(NOVAPDF_FONTS_FORCE_EMBED_PROTECTED, TRUE);
	//if we have some specific fonts that we wish to add to embed/ not emebed lists
	pNova->ClearFontOptions();
	pNova->SetFontOption(L"Arial", TRUE, FALSE);
	pNova->SetFontOption(L"Verdana", FALSE, TRUE);
	pNova->SetFontOption(L"Courier", FALSE, TRUE);
}

//------------------------------------------------------------------------------------------//
//------------------------------------  GRAPHICS OPTIONS  ----------------------------------//
//------------------------------------------------------------------------------------------//

void AddGraphicsOptions(INovaPdfOptions90 *pNova)
{
	//enable image compression
	pNova->SetOptionBool(NOVAPDF_COMPRESS_ENABLE, TRUE);
	// compression settings for high color images - flag, method, level 
	pNova->SetOptionBool(NOVAPDF_COMPRESS_HIGH_COLOR, TRUE);
	pNova->SetOptionLong(NOVAPDF_COMPRESS_HIGH_COLOR_TYPE, COMPRESS_METHOD_JPEG);
	pNova->SetOptionLong(NOVAPDF_COMPRESS_HIGH_COLOR_LEVEL, 77);
	// compression settings for indexed images - flag, method, level 
	pNova->SetOptionBool(NOVAPDF_COMPRESS_INDEXED, TRUE);
	pNova->SetOptionLong(NOVAPDF_COMPRESS_INDEXED_TYPE, COMPRESS_METHOD_ZIP);
	pNova->SetOptionLong(NOVAPDF_COMPRESS_INDEXED_LEVEL, 5);
	// compression settings for monochrome images - flag, method, level 
	pNova->SetOptionBool(NOVAPDF_COMPRESS_MONOCHROM, TRUE);
	pNova->SetOptionLong(NOVAPDF_COMPRESS_MONOCHROM_TYPE, COMPRESS_METHOD_ZIP);
	pNova->SetOptionLong(NOVAPDF_COMPRESS_MONOCHROM_LEVEL, 5);
	// compression settings for text and graphics - flag, method, level 
	pNova->SetOptionBool(NOVAPDF_COMPRESS_TEXT_GRAPHICS, TRUE);
	pNova->SetOptionLong(NOVAPDF_COMPRESS_TEXT_GRAPHICS_TYPE, COMPRESS_METHOD_ZIP);
	pNova->SetOptionLong(NOVAPDF_COMPRESS_TEXT_GRAPHICS_LEVEL, 5);

	//enable downsample
	pNova->SetOptionBool(NOVAPDF_GR_DOWNSMPL_ENABLE, TRUE);
	//downsample high color images - flag, dpi, method
	pNova->SetOptionBool(NOVAPDF_DOWNSAMPLE_HIGH_COLOR, TRUE);
	pNova->SetOptionLong(NOVAPDF_DOWNSAMPLE_RES_HIGH_COLOR, 96);
	pNova->SetOptionLong(NOVAPDF_DOWNSAMPLE_TYPE_HIGH_COLOR, DOWNSAMPLE_FILTER_BICUBIC);
	//downsample indexed images - flag, dpi, method
	pNova->SetOptionBool(NOVAPDF_DOWNSAMPLE_INDEXED, TRUE);
	pNova->SetOptionLong(NOVAPDF_DOWNSAMPLE_RES_INDEXED, 96);
	pNova->SetOptionLong(NOVAPDF_DOWNSAMPLE_TYPE_INDEXED, DOWNSAMPLE_FILTER_BICUBIC);
	//downsample monochrome images - flag, dpi, method
	pNova->SetOptionBool(NOVAPDF_DOWNSAMPLE_MONOCHROM, TRUE);
	pNova->SetOptionLong(NOVAPDF_DOWNSAMPLE_RES_MONOCHROM, 96);
	pNova->SetOptionLong(NOVAPDF_DOWNSAMPLE_TYPE_MONOCHROM, DOWNSAMPLE_FILTER_BICUBIC);

	//enable image convertion
	pNova->SetOptionBool(NOVAPDF_GR_CONVERT_ENABLE, TRUE);
	//convert high color images - flag, type
	pNova->SetOptionBool(NOVAPDF_IMAGE_CONVERT_HIGH_COLOR, TRUE);
	pNova->SetOptionLong(NOVAPDF_IMAGE_CONVERT_TYPE_HIGH_COLOR, CONVERT_GRAYSCALE);
	//if convert to monochrome, set trashold color and dithering method
	pNova->SetOptionLong(NOVAPDF_IMAGE_CONVERT_TRESH_HIGH_COLOR, 128);
	//use or no dithering
	pNova->SetOptionBool(NOVAPDF_IMAGE_DITHER_HIGH_COLOR, TRUE);
	pNova->SetOptionLong(NOVAPDF_IMAGE_DITHER_TYPE_HIGH_COLOR, DITHER_BAYER4);
	//convert indexed images - flag, type
	pNova->SetOptionBool(NOVAPDF_IMAGE_CONVERT_INDEXED, TRUE);
	pNova->SetOptionLong(NOVAPDF_IMAGE_CONVERT_TYPE_INDEXED, CONVERT_GRAYSCALE);
	//if convert to monochrome, set trashold color and dithering method
	pNova->SetOptionLong(NOVAPDF_IMAGE_CONVERT_TRESH_INDEXED, 128);
	//use or no dithering
	pNova->SetOptionBool(NOVAPDF_IMAGE_DITHER_INDEXED, TRUE);
	pNova->SetOptionLong(NOVAPDF_IMAGE_DITHER_TYPE_INDEXED, DITHER_BAYER4);
	//convert text and graphics colors - flag, type
	pNova->SetOptionBool(NOVAPDF_IMAGE_CONVERT_TEXTANDGR, TRUE);
	pNova->SetOptionLong(NOVAPDF_IMAGE_CONVERT_TYPE_TEXTANDGR, CONVERT_GRAYSCALE);
	//if convert to monochrome, set trashold color 
	pNova->SetOptionLong(NOVAPDF_IMAGE_CONVERT_TRESH_TEXTANDGR, 128);
}

//------------------------------------------------------------------------------------------//
//-------------------------------------  OVERLAY OPTIONS  ----------------------------------//
//------------------------------------------------------------------------------------------//

void AddOverlayOptions(INovaPdfOptions90 *pNova)
{
	//set the pdf file you wish to overlay with (with full path)
	pNova->SetOptionLong(NOVAPDF_OVERLAY_FILE_LOCATION, LOCATION_TYPE_LOCAL);
	//pNova->SetOptionString(NOVAPDF_OVERLAY_FILE, L"C:\\... my pdf file");
	pNova->SetOptionString(NOVAPDF_OVERLAY_FILE, L"letterhead-template.pdf");
	//if the file is password protected, enter the password here
	pNova->SetOptionEncryptedString(NOVAPDF_OVERLAY_FILE_PASSWORD, L"");
	//if the overlay file is on a network path, set network user name and password to access this path
	pNova->SetOptionString(NOVAPDF_OVERLAY_USER_NAME, L"");
	pNova->SetOptionEncryptedString(NOVAPDF_OVERLAY_USER_PASSWORD, L"");

	//repeat overlay option
	pNova->SetOptionLong(NOVAPDF_OVERLAY_REPEAT_TYPE, OVERLAY_REPEAT_ALL);
	//opacity
	pNova->SetOptionLong(NOVAPDF_OVERLAY_OPACITY, 50);

	//LAYOUT
	LPWSTR pwsOverlayId, pwsLayoutId;
	//Get signature ID
	pNova->GetOverlay(&pwsOverlayId, &pwsLayoutId);

	//metadata
	pNova->SetLayoutOptionString(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_NAME, L"Overlay Layout");
	pNova->SetLayoutOptionString(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_AUTHOR, L"Hello World application");
	pNova->SetLayoutOptionString(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_DESCRIPTION, L"overlay position on page");

	//anchors
	//percentage or thousands of mm
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_VERTANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_VERTLANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_VERTANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_USE_PERCENT, FALSE);

	//aspect ratio
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_USE_ASPECT_RATIO, FALSE);
	//allow stretch with anchors when print on a different page size or layout
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_ALLOW_STRETCH, FALSE);

	//pages
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_FIRSTPAGE, FALSE);
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_LASTPAGE, FALSE);
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_ODDPAGE, FALSE);
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_EVENPAGE, FALSE);
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_ALLPAGE, TRUE);
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_PAGES, FALSE);
	pNova->SetLayoutOptionString(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_PAGERANGE, L"1-2");
	
	//Rotation (radians)
	pNova->SetLayoutOptionFloat(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_ROTATION, 0);

	//ZIndex (multiple of 5) - objects with higher ZIndex will be above the ones with smaller ZIndex
	pNova->SetLayoutOptionLong(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_ZINDEX, 10);

	//Border
	pNova->SetLayoutOptionBool(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_USE_BORDER, TRUE);
	pNova->SetLayoutOptionLong(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_BORDER_POSITION, BORDER_POSITION_INTERIOR);
	pNova->SetLayoutOptionLong(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_BORDER_WIDTH, 2000);
	pNova->SetLayoutOptionLong(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_BORDER_STYLE, BORDER_STYLE_SOLID);
	pNova->SetLayoutOptionLong(pwsOverlayId, pwsLayoutId, NOVAPDF_LAYOUT_BORDER_COLOR, RGB(200,120,255));
	
	CoTaskMemFree(pwsOverlayId);
	CoTaskMemFree(pwsLayoutId);
}

//------------------------------------------------------------------------------------------//
//-----------------------------------  DIGITAL SIGNATURES  ---------------------------------//
//------------------------------------------------------------------------------------------//

void AddSignatureOptions(INovaPdfOptions90 *pNova)
{
	/*
	//choose a certificate : a certificate installed in the system or from a file
	//if you wish to set a system certificate:
	pNova->SetOptionLong(NOVAPDF_SIGN_CERTIFICATE_TYPE, CERTIFICATE_TYPE_SYSTEM);
	//set system signature information so it can be recognized by novaPDF printer 
	//this information can be retrieved from system using CertOpenSystemStore, CertEnumCertificatesInStore
	//CertGetNameString - CERT_NAME_SIMPLE_DISPLAY_TYPE, CERT_NAME_SIMPLE_DISPLAY_TYPE
	pNova->SetOptionString(NOVAPDF_SIGN_SYSCERT_ISSUEDTO, L"C=..., S=..., L=..., O=..., OU=..., E=..., CN=...");
	pNova->SetOptionString(NOVAPDF_SIGN_SYSCERT_ISSUEDBY, L"C=..., S=..., L=..., O=..., OU=..., E=..., CN=...");
	pNova->SetOptionString(NOVAPDF_SIGN_SYSCERT_FRIENDLYNAME, L"<friendly name>");
	//pCertContext->pCertInfo->Subject
	pNova->SetOptionString(NOVAPDF_SIGN_SYSCERT_SUBJECT, L"C=..., S=..., L=..., O=..., OU=..., E=..., CN=...");
	pNova->SetOptionString(NOVAPDF_SIGN_SYSCERT_SUBJECT_NAME, L"subject name");
	pNova->SetOptionString(NOVAPDF_SIGN_SYSCERT_EXPIRE_DATE, L"2013-01-11T20:17:34Z");
	*/
	
	//if you wish to set a certificate from file:
	pNova->SetOptionLong(NOVAPDF_SIGN_CERTIFICATE_TYPE, CERTIFICATE_TYPE_FILE);
	//certificate file and password
	pNova->SetOptionLong(NOVAPDF_SIGN_FILECERT_LOCATION, LOCATION_TYPE_LOCAL);
	pNova->SetOptionString(NOVAPDF_SIGN_FILECERT_FILE, L"sample.p12");
	//if the file is password protected, enter the password here
	pNova->SetOptionEncryptedString(NOVAPDF_SIGN_FILECERT_FILE_PASSWORD, L"novapdf");
	//if the folder is on a network path, set network user name and password to access this path
	pNova->SetOptionString(NOVAPDF_SIGN_FILECERT_USER_NAME, L"");
	pNova->SetOptionEncryptedString(NOVAPDF_SIGN_FILECERT_USER_PASSWORD, L"");
	
	//customize how the signature will look in the PDF file:
	//show or not the Name on the left 
	pNova->SetOptionBool(NOVAPDF_SIGN_SHOW_GRAPHIC_NAME, TRUE);
	//show or not an image on the left 
	pNova->SetOptionBool(NOVAPDF_SIGN_SHOW_GRAPHIC_IAMGE, TRUE);
	//name - opacity percentage
	pNova->SetOptionLong(NOVAPDF_SIGN_NAME_OPACITY, 50);
	//image file
	pNova->SetOptionLong(NOVAPDF_SIGN_IMAGE_LOCATION, LOCATION_TYPE_LOCAL);
	pNova->SetOptionString(NOVAPDF_SIGN_IMAGE_FILE, L"nopreview.png");
	//if the image file is on a network path, set network user name and password to access this path
	pNova->SetOptionString(NOVAPDF_SIGN_IMAGE_USER_NAME, L"");
	pNova->SetOptionEncryptedString(NOVAPDF_SIGN_IMAGE_USER_PASSWORD, L"");
	//image - keep aspect ratio
	pNova->SetOptionBool(NOVAPDF_SIGN_SHOW_KEEPASPECTRATIO, TRUE);
	//image - opcaity percentage
	pNova->SetOptionLong(NOVAPDF_SIGN_IMAGE_OPACITY, 50);
	//which details to show on the right
	pNova->SetOptionBool(NOVAPDF_SIGN_SHOW_LABELS, FALSE);
	pNova->SetOptionBool(NOVAPDF_SIGN_SHOW_CERTIFICATE_NAME, FALSE);
	pNova->SetOptionBool(NOVAPDF_SIGN_SHOW_SIGN_DATE, FALSE);
	pNova->SetOptionBool(NOVAPDF_SIGN_SHOW_DETAILS, TRUE);
	pNova->SetOptionBool(NOVAPDF_SIGN_SHOW_SIGN_LOCATION, FALSE);
	pNova->SetOptionBool(NOVAPDF_SIGN_SHOW_SIGN_REASON, FALSE);
	pNova->SetOptionBool(NOVAPDF_SIGN_SHOW_CONTACT_INFO, FALSE);
	pNova->SetOptionString(NOVAPDF_SIGN_INFO_REASON, L"<myreason>");
	pNova->SetOptionString(NOVAPDF_SIGN_INFO_LOCATION, L"<mylocation>");
	pNova->SetOptionString(NOVAPDF_SIGN_INFO_CONTACT, L"<mycontactinfo>");
	// if you wish a custom font size on the right
	pNova->SetOptionString(NOVAPDF_SIGN_FONT_NAME, L"Arial");
	pNova->SetOptionLong(NOVAPDF_SIGN_FONT_TYPE, NOVA_FONTTYPE_TRUETYPE);
	pNova->SetOptionBool(NOVAPDF_SIGN_CUSTOM_SIZE, FALSE);
	pNova->SetOptionLong(NOVAPDF_SIGN_FONT_SIZE, 8);
	// font color
	pNova->SetOptionLong(NOVAPDF_SIGN_NAME_COLOR, RGB(255,0,255));

	//visibility
	pNova->SetOptionBool(NOVAPDF_SIGN_VIEW_VIEW, TRUE);
	pNova->SetOptionBool(NOVAPDF_SIGN_VIEW_PRINT, TRUE);
	pNova->SetOptionBool(NOVAPDF_SIGN_VIEW_EXPORT, TRUE);

	//LAYOUT
	LPWSTR pwsSignatureId, pwsLayoutId;
	//Get signature ID
	pNova->GetSignature(&pwsSignatureId, &pwsLayoutId);

	//metadata
	pNova->SetLayoutOptionString(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_NAME, L"Signature Layout");
	pNova->SetLayoutOptionString(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_AUTHOR, L"Hello World application");
	pNova->SetLayoutOptionString(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_DESCRIPTION, L"signature position on page");

	//anchors
	//percentage or thousands of mm
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_OFFSET, 10000);
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_VERTANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_VERTLANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_VERTANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_USE_PERCENT, FALSE);

	//aspect ratio
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_USE_ASPECT_RATIO, FALSE);
	//allow stretch with anchors when print on a different page size or layout
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_ALLOW_STRETCH, FALSE);

	//pages
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_FIRSTPAGE, TRUE);
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_LASTPAGE, FALSE);
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_ODDPAGE, FALSE);
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_EVENPAGE, FALSE);
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_ALLPAGE, FALSE);
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_PAGES, FALSE);
	pNova->SetLayoutOptionString(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_PAGERANGE, L"");
	
	//Width / Height
	pNova->SetLayoutOptionFloat(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_OBJECT_WIDTH, 100000);
	pNova->SetLayoutOptionFloat(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_OBJECT_HEIGHT, 50000);

	//rotation
	//Signatures cannot be rotated!! Leave rotation to 0
	pNova->SetLayoutOptionFloat(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_ROTATION, 0);

	//ZIndex (multiple of 5) - objects with higher ZIndex will be above the ones with smaller ZIndex
	pNova->SetLayoutOptionLong(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_ZINDEX, 25);

	//Border
	pNova->SetLayoutOptionBool(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_USE_BORDER, TRUE);
	pNova->SetLayoutOptionLong(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_BORDER_POSITION, BORDER_POSITION_EXTERIOR);
	pNova->SetLayoutOptionLong(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_BORDER_WIDTH, 1000);
	pNova->SetLayoutOptionLong(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_BORDER_STYLE, BORDER_STYLE_SOLID);
	pNova->SetLayoutOptionLong(pwsSignatureId, pwsLayoutId, NOVAPDF_LAYOUT_BORDER_COLOR, RGB(0,245,0));

	CoTaskMemFree(pwsSignatureId);
	CoTaskMemFree(pwsLayoutId);
}

//------------------------------------------------------------------------------------------//
//-------------------------------------  PAGE CONTENT  -------------------------------------//
//------------------------------------------------------------------------------------------//

void AddPageContentOptions(INovaPdfOptions90 *pNova)
{
	//LAYOUT
	LPWSTR pwsContentId, pwsLayoutId;
	//Get signature ID
	pNova->GetContentLayout(&pwsContentId, &pwsLayoutId);

	//metadata
	pNova->SetLayoutOptionString(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_NAME, L"Content Layout");
	pNova->SetLayoutOptionString(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_AUTHOR, L"Hello World application");
	pNova->SetLayoutOptionString(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_DESCRIPTION, L"printed content position on page");

	//anchors
	//percentage or thousands of mm
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_OFFSET, 15);
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_USE_PERCENT, TRUE);

	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_OFFSET, 15);
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_USE_PERCENT, TRUE);

	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_OFFSET, 15);
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_USE_PERCENT, TRUE);

	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USED, TRUE);
	pNova->SetLayoutOptionFloat(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_OFFSET, 15);
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USE_PERCENT, TRUE);

	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_VERTANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_VERTLANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_VERTANCHOR_USE_PERCENT, FALSE);

	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_USED, FALSE);
	pNova->SetLayoutOptionFloat(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_OFFSET, 0);
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_USE_PERCENT, FALSE);

	//aspect ratio
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_USE_ASPECT_RATIO, FALSE);
	//allow stretch with anchors when print on a different page size or layout
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_ALLOW_STRETCH, TRUE);

	//pages
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_FIRSTPAGE, FALSE);
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_LASTPAGE, FALSE);
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_ODDPAGE, FALSE);
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_EVENPAGE, FALSE);
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_ALLPAGE, TRUE);
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_PAGES, FALSE);
	pNova->SetLayoutOptionString(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_PAGERANGE, L"1-2");
	
	//Rotation (radians)
	pNova->SetLayoutOptionFloat(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_ROTATION, 0);

	//ZIndex (multiple of 5) - objects with higher ZIndex will be above the ones with smaller ZIndex
	pNova->SetLayoutOptionLong(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_ZINDEX, -1);

	//Border
	pNova->SetLayoutOptionBool(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_USE_BORDER, TRUE);
	pNova->SetLayoutOptionLong(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_BORDER_POSITION, BORDER_POSITION_EXTERIOR);
	pNova->SetLayoutOptionLong(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_BORDER_WIDTH, 2000);
	pNova->SetLayoutOptionLong(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_BORDER_STYLE, BORDER_STYLE_SOLID);
	pNova->SetLayoutOptionLong(pwsContentId, pwsLayoutId, NOVAPDF_LAYOUT_BORDER_COLOR, RGB(200,200,200));

	CoTaskMemFree(pwsContentId);
	CoTaskMemFree(pwsLayoutId);
}

//------------------------------------------------------------------------------------------//
//---------------------------------------  SAVE OPTIONS  -----------------------------------//
//------------------------------------------------------------------------------------------//

void AddSaveOptions(INovaPdfOptions90 *pNova)
{
	//choose where to save the pdf file - on the client computer or on the server computer
	pNova->SetOptionLong(NOVAPDF_SAVE_LOCATION, LOCATION_TYPE_LOCAL);

	//what type of save dialog to be shown (none, simple or extended)
	pNova->SetOptionLong(NOVAPDF_SAVE_PROMPT_TYPE, PROMPT_SAVE_NONE);

	//you may choose a predefined folder like "My Documents"
	//pNova->SetOptionLong(NOVAPDF_SAVE_FOLDER_TYPE, SAVEFOLDER_MYDOCUMENTS);

	//or choose a custom folder to save the files
	pNova->SetOptionLong(NOVAPDF_SAVE_FOLDER_TYPE, SAVEFOLDER_CUSTOM);
	pNova->SetOptionString(NOVAPDF_SAVE_FOLDER, L"C:\\temp");

	//if the folder is on a network path, set network user name and password to access this path
	pNova->SetOptionString(NOVAPDF_SAVE_USER_NAME, L"");
	pNova->SetOptionEncryptedString(NOVAPDF_SAVE_USER_PASSWORD, L"");

	//set a macro for the file name
	pNova->SetOptionString(NOVAPDF_SAVE_FILE_NAME, L"test_[N]");

	//in case a file with the same name exists in the selected folder, choose what to do
	pNova->SetOptionLong(NOVAPDF_SAVE_FILEEXIST_ACTION, FILE_CONFLICT_STRATEGY_OVERWRITE);
}

//------------------------------------------------------------------------------------------//
//---------------------------------------  MERGE OPTIONS  -----------------------------------//
//------------------------------------------------------------------------------------------//

void AddMergeOptions(INovaPdfOptions90 *pNova)
{
	//Enable Merge PDF option
	pNova->SetOptionBool(NOVAPDF_MERGE_ENABLE, TRUE);
	//show a dialog before printing each document to enter merge options
	pNova->SetOptionBool(NOVAPDF_SHOW_MERGE_DLG, FALSE);

	//merge file type: 
	//NOVAPDF_MERGE_IF_FILE_EXISTS = TRUE - if a PDF with the same name exists in the Save folder, the new pages will be appended
	//this option is usefull when printing multiple documents and wish to add them to the same PDF file
	//NOVAPDF_MERGE_IF_FILE_EXISTS = FALSE - merge with another file specified in NOVAPDF_MERGE_OTHER_FILE option
	//this is usefull if for instance you wish to add a title page at the beginning of each PDF you create
	pNova->SetOptionBool(NOVAPDF_MERGE_IF_FILE_EXISTS, TRUE);

	//if merge with other PDF file (NOVAPDF_MERGE_IF_FILE_EXISTS = FALSE) 
	//choose where is existing PDF file located - on the client computer or on the server computer
	pNova->SetOptionLong(NOVAPDF_MERGE_LOCATION, LOCATION_TYPE_LOCAL);
	
	//Existing PDF for merge
	pNova->SetOptionString(NOVAPDF_MERGE_OTHER_FILE, L"C:\\temp\\title.pdf");

	//if the folder is on a network path, set network user name and password to access this path
	pNova->SetOptionString(NOVAPDF_MERGE_USER, L"");
	pNova->SetOptionEncryptedString(NOVAPDF_MERGE_PASSWORD, L"");

	//Merge type: append at the end, insert at the beginning or insert at a specified page number
	pNova->SetOptionLong(NOVAPDF_MERGE_TYPE, MERGE_TYPE_APPEND);

	//if merge type is MERGE_TYPE_INSERT_PAGENO set where in the pdf to insert the pages
	pNova->SetOptionLong(NOVAPDF_MERGE_INSERT_PAGENO, 3);

	//in case existing pdf file is password protected, enter the password here
	pNova->SetOptionEncryptedString(NOVAPDF_MERGE_APPEND_PASSWORD, L"my password");
}

//------------------------------------------------------------------------------------------//
//-----------------------------------------  ACTIONS  --------------------------------------//
//------------------------------------------------------------------------------------------//

void AddAction_OpenFile(INovaPdfOptions90 *pNova, LPWSTR* ppwsActionID)
{
	LONG nActionIndex;
	pNova->AddAction(NOVA_ACTION_OPEN, L"My Open Action", ppwsActionID, &nActionIndex);
	//Execute this action	
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_EXECUTE, TRUE);
	//if action fails, execute the other actions
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_CONTINUE);
	//open original pdf file (the pdf file that was generated now)
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_OPEN_OPENORIGINAL, TRUE);
	// if NOVAPDF_ACTION_OPEN_OPENORIGINAL is FALSE, open custom file; 
	//pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_OPEN_OPENORIGINAL, FALSE);
	//pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_OPEN_CUSTOMSOURCE, L"C:\\temp\\<file to open>.pdf");
}
//------------------------------------------------------------------------------------------//
void AddAction_RunApplication(INovaPdfOptions90 *pNova, LPWSTR* ppwsActionID)
{
	LONG nActionIndex;
	pNova->AddAction(NOVA_ACTION_RUN, L"My Run Action", ppwsActionID, &nActionIndex);
	//Execute this action	
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_EXECUTE, TRUE);
	//if action fails, do not execute the other actions
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_STOP);
	//set application to be run
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_RUN_APPLICATION, L"C:\\Program Files (x86)\\Adobe\\Acrobat Reader DC\\Reader\\AcroRd32.exe");
	//command line parameters for the application; %1 will be replaced with the generated PDF file name (with full path)
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_RUN_CMDLINE_PARAMETERS, L"%1");
	//user and password to connect to the application folder
	//pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_RUN_USER_NAME, L"user");
	//pNova->SetActionOptionEncryptedString(*ppwsActionID, NOVAPDF_ACTION_RUN_USER_PASSWORD, L"password");
	//Show or hide application window
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_RUN_SHOW, RUN_NORMAL);
	//Start tha application as child process or with ShellExecute
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_RUN_SHELL, TRUE);
}
//------------------------------------------------------------------------------------------//
void AddAction_CopyFile(INovaPdfOptions90 *pNova, LPWSTR* ppwsActionID)
{
	LONG nActionIndex;
    //add a copy file action before generating pdf (if for instance we wish to append to an existing pdf)
	pNova->AddAction(NOVA_ACTION_COPY, L"My Copy action", ppwsActionID, &nActionIndex);
	//Execute this action	
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_EXECUTE, TRUE);
	//if action fails, do not execute the other actions
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_STOP);
	//copy source: custom file
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_COPY_SOURCECOPYORIGINAL, FALSE);
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_COPY_CUSTOMSOURCE, L"%PROGRAMDATA%\\Softland\\novaPDF 9\\nPdfSdk9_Softland\\DefaultFiles\\invoice-text.pdf");
	//user and password to connect to pdf file
	//pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_COPY_SOURCEUSERNAME, L"user");
	//pNova->SetActionOptionEncryptedString(*ppwsActionID, NOVAPDF_ACTION_COPY_SOURCEPASSWORD, L"password");
	//copy destination: new created pdf that will be appended
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_COPY_DESTCOPYORIGINAL, TRUE);
	// if NOVAPDF_ACTION_COPY_DESTCOPYORIGINAL is FALSE, set folder and file name for destination
	//pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_COPY_DESTCOPYORIGINAL, FALSE);
	//pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_COPY_CUSTOMDESTFOLDER, L"C:\\temp");
	//pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_COPY_CUSTOMDESTFILE, L"<my pdf file>.pdf");
	//pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_COPY_DESTKEEPFILENAME, FALSE);
	//user and password to connect to folder
	//pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_COPY_DESTUSERNAME, L"user");
	//pNova->SetActionOptionEncryptedString(*ppwsActionID, NOVAPDF_ACTION_COPY_DESTPASSWORD, L"password");
}
//------------------------------------------------------------------------------------------//
void AddAction_DeleteFile(INovaPdfOptions90 *pNova, LPWSTR* ppwsActionID)
{
	LONG nActionIndex;
	pNova->AddAction(NOVA_ACTION_DELETE, L"My Delete Action", ppwsActionID, &nActionIndex);
	//Execute this action	
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_EXECUTE, TRUE);
	//if action fails, execute the other actions
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_CONTINUE);
	//delete original pdf file
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_DELETE_DELETEORIGINAL, TRUE);
	// if NOVAPDF_ACTION_DELETE_DELETEORIGINAL is TRUS, set the name of file to delete
	//pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_DELETE_DELETEORIGINAL, FALSE);
	//pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_DELETE_CUSTOMSOURCE, L"C:\\temp\\<file to delete>.pdf");
	//user and password to connect to pdf file
	//pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_DELETE_USERNAME, L"user");
	//pNova->SetActionOptionEncryptedString(*ppwsActionID, NOVAPDF_ACTION_DELETE_PASSWORD, L"password");
}
//------------------------------------------------------------------------------------------//
void AddAction_EmailMAPI(INovaPdfOptions90 *pNova, LPWSTR* ppwsActionID)
{
	LONG nActionIndex;
	pNova->AddAction(NOVA_ACTION_EMAILMAPI, L"My Email MAPI Action", ppwsActionID, &nActionIndex);
	//Execute this action	
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_EXECUTE, TRUE);
	//if action fails, execute the other actions
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_CONTINUE);
	//Show dialog before printing each document to enter email address
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SHOW_DIALOG, FALSE);

	//Email MAPI method (show dialog or send automatically)
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_EMAILMAPI_SENDEMAIL, EMAIL_TYPE_MAPI_DLG);

	//Email details
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILMAPI_SUBJECT, L"my email subject");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILMAPI_BODY, L"my email body");

	//flag if the addresses should be looked up in the address book
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_EMAILMAPI_LOOKUP_ADDRESS, FALSE);

	//flag - if the PDF should be sent as zip compression
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_EMAILMAPI_COMPRESS, FALSE);

	//flag - change the extension for the compressed zip attachment
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_EMAILMAPI_CHANGEEXTENSION, FALSE);
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILMAPI_EXTENSION, L"txt");

    //attach the PDF to the email
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_EMAILMAPI_ATTACH_PDF, TRUE);

    //attach other file to the email
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_EMAILMAPI_ATTACH_OTHER_FILES, FALSE);
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILMAPI_OTHER_FILES, L"path to other files to attach");

	//Set receipient addresses 
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILMAPI_FROM, L"from_adress");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILMAPI_TO, L"to_adress");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILMAPI_CC, L"cc_adress");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILMAPI_BCC, L"bcc_adress");
}
//------------------------------------------------------------------------------------------//
void AddAction_EmailSMTP(INovaPdfOptions90 *pNova, LPWSTR* ppwsActionID)
{
	LONG nActionIndex;
	pNova->AddAction(NOVA_ACTION_EMAILSMTP, L"My Email SMTP Action", ppwsActionID, &nActionIndex);
	//Execute this action	
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_EXECUTE, TRUE);
	//if action fails, execute the other actions
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_CONTINUE);
	//Show dialog before printing each document to enter email address
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SHOW_DIALOG, FALSE);

	//SMTP server name and port
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILSMTP_SERVER, L"my SMTP server name");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILSMTP_PORT, L"25");

	//SMTP account
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILSMTP_ACCOUNT, L"my SMTP user name");
	pNova->SetActionOptionEncryptedString(*ppwsActionID, NOVAPDF_EMAILSMTP_PASSWORD, L"my SMTP password");

	//flags, if the SMTP server requires Authentification or SSL (1 or 0)
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_EMAILSMTP_SSL, FALSE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_EMAILSMTP_TLS, FALSE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_EMAILSMTP_AUTHENTICATION, FALSE);

	//Email details
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILSMTP_SUBJECT, L"my email subject");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILSMTP_BODY, L"my email body");

	//flag - if the PDF should be sent as zip compression
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_EMAILSMTP_COMPRESS, FALSE);

	//flag - change the extension for the compressed zip attachment
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_EMAILSMTP_CHANGEEXTENSION, FALSE);
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILSMTP_EXTENSION, L"txt");

    //attach the PDF to the email
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_EMAILSMTP_ATTACH_PDF, TRUE);

    //attach other file to the email
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_EMAILSMTP_ATTACH_OTHER_FILES, FALSE);
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILSMTP_OTHER_FILES, L"path to other files to attach");

	//Set receipient addresses 
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILSMTP_FROM, L"from adress");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILSMTP_TO, L"to adress");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILSMTP_CC, L"cc adress");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_EMAILSMTP_BCC, L"bcc adress");
}
//------------------------------------------------------------------------------------------//
void AddAction_FTP(INovaPdfOptions90 *pNova, LPWSTR* ppwsActionID)
{
	LONG nActionIndex;
	pNova->AddAction(NOVA_ACTION_FTP, L"My FTP Action", ppwsActionID, &nActionIndex);
	//Execute this action	
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_EXECUTE, TRUE);
	//if action fails, execute the other actions
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_CONTINUE);

	//original pdf file
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_FTP_SOURCEORIGINAL, TRUE);
	// if NOVAPDF_ACTION_FTP_SOURCEORIGINAL is FALSE, set the name of file to upload
	//pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_FTP_SOURCEORIGINAL, FALSE);
	//pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_FTP_SOURCEFILE, L"C:\\temp\\<file to upload>");
	//user and password to connect to source pdf file
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_FTP_SOURCEUSER, L"user");
	pNova->SetActionOptionEncryptedString(*ppwsActionID, NOVAPDF_ACTION_FTP_SOURCEPASSWORD, L"password");
	//destination folder
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_FTP_DESTFOLDER, L"test");
	//use the same file name
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_FTP_KEEPFILENAME, TRUE);
	//or change file name
	//pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_FTP_KEEPFILENAME, FALSE);
	//pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_FTP_DESTFILE, L"<new file name>");
	//ftp server
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_FTP_SERVER, L"192.168.1.1");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_FTP_PORT, L"21");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_FTP_USERNAME, L"user");
	pNova->SetActionOptionEncryptedString(*ppwsActionID, NOVAPDF_ACTION_FTP_PASSWORD, L"password");
	//host
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_FTP_HOST, L"");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_FTP_HOSTPORT, L"80");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_FTP_HOSTUSERNAME, L"");
	pNova->SetActionOptionEncryptedString(*ppwsActionID, NOVAPDF_ACTION_FTP_HOSTPASSWORD, L"");
	//ftp options
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_FTP_UPLOADSPEEDCHECK, FALSE);
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_FTP_UPLOADSPEED, 200);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_FTP_USEPASSIVEMODE, FALSE);
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_FTP_TIMEOUT, 30);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_FTP_RETRY, FALSE);
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_FTP_RETRYVALUE, 2);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_FTP_WAIT, FALSE);
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_FTP_WAITVALUE, 60);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_FTP_SSL, FALSE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_FTP_USEPROXY, FALSE);
}
//------------------------------------------------------------------------------------------//
void AddAction_SFTP(INovaPdfOptions90 *pNova, LPWSTR* ppwsActionID)
{
	LONG nActionIndex;
	pNova->AddAction(NOVA_ACTION_SFTP, L"My SFTP Action", ppwsActionID, &nActionIndex);
	//Execute this action	
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_EXECUTE, TRUE);
	//if action fails, execute the other actions
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_CONTINUE);

	//upload original pdf file
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_SOURCEORIGINAL, TRUE);
	//or upload a custom file
	//pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_SOURCEORIGINAL, FALSE);
	//pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_SFTP_SOURCEFILE, L"C:\\temp\\<custom file>");
	//user and password to connect to source pdf file
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_SFTP_SOURCEUSER, L"");
	pNova->SetActionOptionEncryptedString(*ppwsActionID, NOVAPDF_ACTION_SFTP_SOURCEPASSWORD, L"");
	//destination folder
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_SFTP_DESTFOLDER, L"test");
	// destination file name - use the same file name
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_KEEPFILENAME, TRUE);
	// or change file name
	//pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_KEEPFILENAME, FALSE);
	//pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_SFTP_DESTFILE, L"<new file name>");
	//sftp server
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_SFTP_SERVER, L"192.168.1.1");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_SFTP_PORT, L"22");
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_SFTP_USERNAME, L"user");
	pNova->SetActionOptionEncryptedString(*ppwsActionID, NOVAPDF_ACTION_SFTP_PASSWORD, L"password");
	//sftp options
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_USEPRIVATEKEY, FALSE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_UPLOADSPEEDCHECK, FALSE);
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_SFTP_UPLOADSPEED, 200);
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_SFTP_TIMEOUT, 30);
	pNova->SetActionOptionString(*ppwsActionID, NOVAPDF_ACTION_SFTP_KEYFILENAME, L"");
	pNova->SetActionOptionEncryptedString(*ppwsActionID, NOVAPDF_ACTION_SFTP_KEYFILEPASSWORD, L"");
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_RETRY, FALSE);
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_SFTP_RETRYVALUE, 2);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_WAIT, FALSE);
	pNova->SetActionOptionLong(*ppwsActionID, NOVAPDF_ACTION_SFTP_WAITVALUE, 30);


	//Authentications
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_AUTH_PUBLICKEY, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_AUTH_PASSWORD, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_AUTH_KEYBOARDINT, TRUE);
	//Ciphers
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_AES256CTR, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_3DESCBC, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_AES128CBC, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_AES192CBC, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_AES256CBC, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_BLOWFISHCBC, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_TWOFISHCBC, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_TWOFISH192CBC, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_TWOFISH128CBC, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_TWOFISH256CBC, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_ARCFOUR, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_ARCFOUR128, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_ARCFOUR256, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_CAST128CBC, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_AES128CTR, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_CIPHER_AES192CTR, TRUE);
	//MACs	
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_MAC_MD5, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_MAC_SHA1, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_MAC_SHA2256, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_MAC_SHA225696, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_MAC_RIPEMD160, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_MAC_RIPEMD160OPENSSH, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_MAC_MD596, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_MAC_SHA196, TRUE);
	//Compression
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_COMPRESS_NONE, TRUE);
	pNova->SetActionOptionBool(*ppwsActionID, NOVAPDF_ACTION_SFTP_COMPRESS_ZLIBOPENSSH, TRUE);
}
//------------------------------------------------------------------------------------------//
//------------------------------------------------------------------------------------------//
void DeleteActionType(INovaPdfOptions90 *pNova, LONG nActionType)
{
	LPWSTR pwsActionID = NULL;
	LONG nCount, n, nType;

	pNova->GetActionCount( &nCount );
	n = nCount - 1;
	//parse actions
	while (n >= 0)
	{
		pNova->GetAction(n, &pwsActionID, &nType);
		//delete all actions of given type
		if (nType == nActionType)
		{
			pNova->DeleteAction(pwsActionID);
		}
		n--;
		CoTaskMemFree(pwsActionID);
		pwsActionID = NULL;
	}
}
//------------------------------------------------------------------------------------------//
// There can be added actions to manipulate files (copy or delete), to run applications (open or run), 
//   to send the pdf by email (MAPI or SMTP) or to upload the pdf (with FTP or SFTP)
// Next there is an exemple of actions that append the new generated pdf to an existing one, 
//  send it by email and then deletes the pdf. There are used next actions
// - a copy action that copies the original pdf that must be appended; this action will be performed before generating the pdf
// - an email MAPI action
// - a delete action
//------------------------------------------------------------------------------------------//
void AddActionsOptions(INovaPdfOptions90 *pNova)
{
	LPWSTR pwsActionID = NULL;
	
	//DO NOT OPEN PDF 
	//an Open action is added by default in the profile - delete or disable this open action
	pNova->DisableActionType(NOVA_ACTION_OPEN);

	//add action copy; will copy the file that will be appended 
	AddAction_CopyFile(pNova, &pwsActionID);
	//set action index to 1 - first in the actions list - so it is executed before generate pdf
	pNova->SetActionOptionLong(pwsActionID, NOVAPDF_ACTION_INDEX, 0);
	CoTaskMemFree(pwsActionID);
	pwsActionID = NULL;

	//modify save options to append to existing pdf
	AddSaveOptions(pNova);

	//add action email MAPI - open default rmail client send email window
    AddAction_EmailMAPI(pNova, &pwsActionID);
	CoTaskMemFree(pwsActionID);
	pwsActionID = NULL;

	//add action delete - delete created pdf file
	AddAction_DeleteFile(pNova, &pwsActionID);
	CoTaskMemFree(pwsActionID);
	pwsActionID = NULL;

/*
	//add action run application
    AddAction_RunApplication(pNova, &pwsActionID);
	CoTaskMemFree(pwsActionID);
	pwsActionID = NULL;

	//add action open file
    AddAction_OpenFile(pNova, &pwsActionID);
	CoTaskMemFree(pwsActionID);
	pwsActionID = NULL;

	//add action email SMTP
    AddAction_EmailSMTP(pNova, &pwsActionID);
	CoTaskMemFree(pwsActionID);
	pwsActionID = NULL;

	//add action FTP
    AddAction_FTP(pNova, &pwsActionID);
	CoTaskMemFree(pwsActionID);
	pwsActionID = NULL;

	//add action SFTP
    AddAction_SFTP(pNova, &pwsActionID);
	CoTaskMemFree(pwsActionID);
	pwsActionID = NULL;

*/
}
//------------------------------------------------------------------------------------------//
